ExDisco.Releases.MasterVersion (ex_disco v0.1.0)

Copy Markdown View Source

A single release version returned by the master versions endpoint.

When querying /masters/{id}/versions, each item in the list is a MasterVersion — one concrete pressing or edition of the master recording.

Fields

  • :id — Discogs release ID for this version
  • :title — Title of this version
  • :status — Review status (e.g. "Accepted")
  • :format — Physical format string (e.g. "12\", 33 ⅓ RPM")
  • :country — Country of release
  • :label — Record label name
  • :released — Release year as a string (e.g. "1993")
  • :catno — Catalog number
  • :major_formats — High-level format categories (e.g. ["Vinyl"])
  • :thumb — Thumbnail image URL
  • :resource_url — Full API URL for this release
  • :community_in_collection — How many Discogs users have this in their collection
  • :community_in_wantlist — How many Discogs users want this

Summary

Types

t()

@type t() :: %ExDisco.Releases.MasterVersion{
  catno: String.t() | nil,
  community_in_collection: non_neg_integer() | nil,
  community_in_wantlist: non_neg_integer() | nil,
  country: String.t() | nil,
  format: String.t() | nil,
  id: pos_integer(),
  label: String.t() | nil,
  major_formats: [String.t()],
  released: String.t() | nil,
  resource_url: String.t() | nil,
  status: String.t() | nil,
  thumb: String.t() | nil,
  title: String.t()
}