The average rating and the total number of user ratings for a given release.
Summary
Types
@type t() :: %ExDisco.Releases.Rating{average: float(), count: pos_integer()}
The average rating and the total number of user ratings for a given release.
@type t() :: %ExDisco.Releases.Rating{average: float(), count: pos_integer()}